
local CustomDecoration = ...

local _PrefixAsset = "CUSTOM_DECORATION_V1_"

-- Apply building asset processor
CustomDecoration:registerAssetProcessor("models/decorations/decoration.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
CustomDecoration:registerAssetProcessor("models/decorations/decoration3.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
CustomDecoration:registerAssetProcessor("models/decorations/stairs.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
CustomDecoration:registerAssetProcessor("models/decorations/stainedGlass.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Create default building part registering function 
function registerDefaultBuildingPart(_nodePrefix)
	CustomDecoration:register({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		Mover = { DataType = "BUILDING_PART_MOVER" },
		ConstructorData = {
                    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                    CoreObjectPrefab = _nodePrefix .. "_PREFAB"
                }
	})
end

-- Register Main prefab nodes
CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/step_1_Ladder_Tiling1Part", _PrefixAsset .. "TILING1_PREFAB")
CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/step_2_Ladder_Tiling2Part", _PrefixAsset .. "TILING2_PREFAB")
--------------------------------------------------------------------------

local defaultNodePrefixList = {
	_PrefixAsset .. "TILING1",
	_PrefixAsset .. "TILING2"
}

-- Register simple building part assets
for i, nodePrefix in ipairs(defaultNodePrefixList) do
	registerDefaultBuildingPart(nodePrefix)
end

-- Create default minor decoration part registering function 
function registerDefaultMinorDecorationPart(_nameFbxBase, _nameFbxModel, _nameFbx, _nameAsset, _stoneCost)
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "Part", _PrefixAsset ..  _nameAsset .. "_PREFAB")

    function registerDecorationPart(_prefixAssetTop, _moverType, _stoneCost2)
        CustomDecoration:register({
        	DataType = "BUILDING_PART",
	        Id = _prefixAssetTop .. _nameAsset .. "_PART",
	        Name = _prefixAssetTop .. _nameAsset .. "_NAME",
	        Description = _prefixAssetTop .. _nameAsset .. "_DESC",
	        Category = "DECORATION",
	        Mover = { DataType = _moverType },
	        ConstructorData = {
		    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		    CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_PREFAB",
                    IsPreviewGroundVisible = false
	        },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
	            },
		    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _stoneCost2 }
		    }
	        }
        })
    end

    registerDecorationPart(_PrefixAsset .. "TOP_", "BUILDING_PART_MOVER", 0)
    registerDecorationPart("STONE_GATE_V5_DECORATION_", "BUILDING_PART_MOVER_INSTANCE", _stoneCost)

    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR", -- Snaps the decoration only on minor attach nodes (here only on the facades)
  	HasBuildingZone = true,
	BuildingZone = { 0, 0 }
    })

-- Register Main prefab nodes
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/step_0_Ladder_" .. _nameFbx .. "_RootPart", _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB")

-- Register the root part
    CustomDecoration:register({
	DataType = "BUILDING_PART",
	Id = _PrefixAsset .. _nameAsset .. "_ROOT_PART",
	Name = _PrefixAsset .. _nameAsset .. "_ROOT_NAME",
	Description = _PrefixAsset .. _nameAsset .. "_ROOT_DESC",
	Category = "DECORATION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB",
		EndPart = _PrefixAsset .. "TOP_" .. _nameAsset .. "_PART",
		FillerList = {
			_PrefixAsset .. "TILING2_PART"
                },
		BasementFillerList = {
			_PrefixAsset .. "TILING1_PART"
         	},
		MinimumScale = 0,
		BasementScale = 1,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 0 }
		}
	}
    })

-- Override building part components properties (generated by the building asset processor) to add building zones
    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/step_0_Ladder_" .. _nameFbx .. "_RootPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0, 0 }
    })
end

registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "SFenetre", "SFENETRE", 1)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "LFenetre", "LFENETRE", 1)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "PFenetre", "PFENETRE", 1)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "ArrowSlit", "ARROWSLIT", 1)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "Lucarne", "LUCARNE", 1)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "Lucarne2", "LUCARNE2", 1)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "Lucarne3", "LUCARNE3", 1)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "Lucarne4", "LUCARNE4", 1)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "Balcony", "BALCONY", 2)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "Balcony2", "BALCONY2", 2)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "Balcony3", "BALCONY3", 2)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "Balcony4", "BALCONY4", 2)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "Chimney", "CHIMNEY", 1)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "Tourelle", "TURRET", 2)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "Tourelle2", "TURRET2", 2)
registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "Tourelle3", "TURRET3", 2)

--[[
CustomDecoration:registerAssetProcessor("models/decorations/spire.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

function registerSpire(_nameFbxBase, _nameFbxModel,  _nameFbx, _nameAsset, _stoneCost)

-- Register common prefab nodes
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "/step_0_" .. _nameFbx .. "_RootPart", _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB")
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "/step_4_" .. _nameFbx .. "_TopPart", _PrefixAsset ..  _nameAsset .. "_TOP_PREFAB")
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "/step_1_" .. _nameFbx .. "_Tiling2Part", _PrefixAsset ..  _nameAsset .. "_TILING2_PREFAB")
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "/step_2_" .. _nameFbx .. "_Tiling3Part", _PrefixAsset ..  _nameAsset .. "_TILING3_PREFAB")
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "/step_3_" .. _nameFbx .. "_Tiling4Part", _PrefixAsset ..  _nameAsset .. "_TILING4_PREFAB")

    local defaultNodePrefixList = {
	_PrefixAsset .. _nameAsset .. "_TOP",
	_PrefixAsset .. _nameAsset .. "_TILING2",
	_PrefixAsset .. _nameAsset .. "_TILING3",
	_PrefixAsset .. _nameAsset .. "_TILING4"
    }

-- Register simple building part assets
    for i, nodePrefix in ipairs(defaultNodePrefixList) do
	registerDefaultBuildingPart(nodePrefix)
    end

-- Register the pole flag part
    CustomDecoration:register({
	DataType = "BUILDING_PART",
	Id = _PrefixAsset .. _nameAsset .. "_ROOT_PART",
	Name = _PrefixAsset .. _nameAsset .. "_ROOT_NAME",
	Description = _PrefixAsset .. _nameAsset .. "_ROOT_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB",
		EndPart = _PrefixAsset .. _nameAsset .. "_TOP_PART",
		FillerList = {
			_PrefixAsset .. _nameAsset .. "_TILING4_PART",
			_PrefixAsset .. _nameAsset .. "_TILING3_PART"
                },
		BasementFillerList = {
			_PrefixAsset .. _nameAsset .. "_TILING2_PART"
         	},
		MinimumScale = 0,
		BasementScale = 1,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
                        { Resource = "STONE", Quantity = _stoneCost }
		}
	}
    })

-- Override building part components properties (generated by the building asset processor) to add building zones

    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "/step_0_" .. _nameFbx .. "_RootPart", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR", -- Snaps the decoration only on minor attach nodes (here only on the facades)
	HasBuildingZone = true,
	BuildingZone = { 0, 0 }
    })
end

registerSpire("spire", "spires", "spire1", "SPIRE1", 0)
--]]

-- Register air vent particle system (smoke)
    CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/ChimneyPart/SmokeEmitter", "CUSTOM_CHIMNEY_SMOKE_EMITTER_PREFAB")

    CustomDecoration:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/ChimneyPart", {
	DataType = "COMP_BUILDING_PART",
	FeedbackComponentListToActivate = {
                 { "CUSTOM_CHIMNEY_SMOKE_EMITTER_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" }
	}
    })

    CustomDecoration:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/ChimneyPart/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "PARTICLE_SYSTEM_HOUSING_SMOKE",
	IsPlaying = true,
	IsEmitting = true
    })

    CustomDecoration:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/ChimneyPart/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
    })

registerDefaultMinorDecorationPart("decoration", "decoration/Minor", "ChimneyB", "CHIMNEY_B", 1)
registerDefaultMinorDecorationPart("decoration3", "commonDecoration", "roundWindow2", "STONE_ROUND_WINDOW", 1)

-- Create stained glass minor decoration part registering function 
function registerStainedGlassMinorDecorationPart(_nameFbxBase, _nameFbxModel, _nameFbx, _nameAsset, _stoneCost)
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "Part", _PrefixAsset ..  _nameAsset .. "_PREFAB")

    function registerDecorationPart(_prefixAssetTop, _moverType, _stoneCost2)
        CustomDecoration:register({
        	DataType = "BUILDING_PART",
	        Id = _prefixAssetTop .. _nameAsset .. "_PART",
	        Name = _prefixAssetTop .. _nameAsset .. "_NAME",
	        Description = _prefixAssetTop .. _nameAsset .. "_DESC",
	        Category = "DECORATION",
	        Mover = { DataType = _moverType },
	        ConstructorData = {
		    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		    CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_PREFAB",
                    IsPreviewGroundVisible = false
	        },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
	            },
		    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "GLASS", Quantity = _stoneCost2 }
		    }
	        }
        })
    end

    registerDecorationPart(_PrefixAsset .. "TOP_", "BUILDING_PART_MOVER", 0)
    registerDecorationPart("CHURCH_V1_DECORATION_", "BUILDING_PART_MOVER_INSTANCE", _stoneCost)

    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR", -- Snaps the decoration only on minor attach nodes (here only on the facades)
  	HasBuildingZone = true,
	BuildingZone = { 0, 0 }
    })

-- Register Main prefab nodes
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/step_0_Ladder_" .. _nameFbx .. "_RootPart", _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB")

-- Register the root part
    CustomDecoration:register({
	DataType = "BUILDING_PART",
	Id = _PrefixAsset .. _nameAsset .. "_ROOT_PART",
	Name = _PrefixAsset .. _nameAsset .. "_ROOT_NAME",
	Description = _PrefixAsset .. _nameAsset .. "_ROOT_DESC",
	Category = "DECORATION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB",
		EndPart = _PrefixAsset .. "TOP_" .. _nameAsset .. "_PART",
		FillerList = {
			_PrefixAsset .. "TILING2_PART"
                },
		BasementFillerList = {
			_PrefixAsset .. "TILING1_PART"
         	},
		MinimumScale = 0,
		BasementScale = 1,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 0 }
		}
	}
    })

-- Override building part components properties (generated by the building asset processor) to add building zones
    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/step_0_Ladder_" .. _nameFbx .. "_RootPart", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR", -- Snaps the decoration only on minor attach nodes (here only on the facades)
	HasBuildingZone = true,
	BuildingZone = { 0, 0 }
    })
end

registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "stainedGlassWindow1", "STAINED_GLASS_WINDOW_1", 10)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlass1", "STAINED_GLASS_1", 10)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlass2", "STAINED_GLASS_2", 10)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlass3", "STAINED_GLASS_3", 10)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlass4", "STAINED_GLASS_4", 10)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlass8", "STAINED_GLASS_8", 10)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "PStainedGlass1", "P_STAINED_GLASS_1", 7)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlassTall1", "STAINED_GLASS_TALL_1", 7)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlassTall2", "STAINED_GLASS_TALL_2", 7)

-- Create specific decoration part registering function 
function registerDefaultMajorDecorationPart(_nameFbx, _nameAsset, _stoneCost)
    CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", _PrefixAsset ..  _nameAsset .. "_PREFAB")

    function registerDecorationPart(_prefixAssetTop, _moverType, _stoneCost2)
        CustomDecoration:register({
        	DataType = "BUILDING_PART",
	        Id = _prefixAssetTop .. _nameAsset .. "_PART",
	        Name = _prefixAssetTop .. _nameAsset .. "_NAME",
	        Description = _prefixAssetTop .. _nameAsset .. "_DESC",
	        Category = "DECORATION",
	        Mover = { DataType = _moverType },
	        ConstructorData = {
		    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		    CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_PREFAB",
                    IsPreviewGroundVisible = false
	        },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
	            },
		    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _stoneCost2 }
		    }
	        }
        })
    end

    registerDecorationPart(_PrefixAsset .. "TOP_", "BUILDING_PART_MOVER", 0)
--    registerDecorationPart("STONE_GATE_V5_DECORATION_", "BUILDING_PART_MOVER_INSTANCE")

    CustomDecoration:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
--	BuildingPartType = "MINOR", -- Snaps the decoration only on minor attach nodes (here only on the facades)
  	HasBuildingZone = true,
	BuildingZone = { 0, 0 }
    })

-- Register Main prefab nodes
    CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/step_0_Ladder_" .. _nameFbx .. "_RootPart", _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB")

-- Register the root part
    CustomDecoration:register({
	DataType = "BUILDING_PART",
	Id = _PrefixAsset .. _nameAsset .. "_ROOT_PART",
	Name = _PrefixAsset .. _nameAsset .. "_ROOT_NAME",
	Description = _PrefixAsset .. _nameAsset .. "_ROOT_DESC",
	Category = "DECORATION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB",
		EndPart = _PrefixAsset .. "TOP_" .. _nameAsset .. "_PART",
		FillerList = {
			_PrefixAsset .. "TILING2_PART"
                },
		BasementFillerList = {
			_PrefixAsset .. "TILING1_PART"
         	},
		MinimumScale = 0,
		BasementScale = 1,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 0 }
		}
	}
    })

-- Override building part components properties (generated by the building asset processor) to add building zones
    CustomDecoration:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/step_0_Ladder_" .. _nameFbx .. "_RootPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0, 0 }
    })
end

registerDefaultMajorDecorationPart("DoorA", "DOOR_A", 1)
registerDefaultMajorDecorationPart("DoorB", "DOOR_B", 1)

-- Create wooden decoration part registering function 
CustomDecoration:registerAssetProcessor("models/decorations/woodenDecoration.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
CustomDecoration:registerAssetProcessor("models/decorations/woodenDecoration2.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

function registerDefaultWoodenDecorationPart(_nameFbxBase, _nameFbxModel, _nameFbx, _nameAsset, _woodCost)
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/".. _nameFbxModel .. "/" .. _nameFbx .. "Part", _PrefixAsset ..  _nameAsset .. "_PREFAB")

    function registerDecorationPart(_prefixAssetTop, _moverType, _woodCost2)
        CustomDecoration:register({
        	DataType = "BUILDING_PART",
	        Id = _prefixAssetTop .. _nameAsset .. "_PART",
	        Name = _prefixAssetTop .. _nameAsset .. "_NAME",
	        Description = _prefixAssetTop .. _nameAsset .. "_DESC",
	        Category = "DECORATION",
	        Mover = { DataType = _moverType },
	        ConstructorData = {
		    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		    CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_PREFAB",
                    IsPreviewGroundVisible = false
	        },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
	            },
		    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = _woodCost2 }
		    }
	        }
        })
    end

    registerDecorationPart(_PrefixAsset .. "TOP_", "BUILDING_PART_MOVER", 0) -- wood cost is forced to 0
--    registerDecorationPart("STONE_GATE_V5_DECORATION_", "BUILDING_PART_MOVER_INSTANCE")

    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/".. _nameFbxModel .. "/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
--	BuildingPartType = "MINOR", -- Snaps the decoration only on minor attach nodes (here only on the facades)
  	HasBuildingZone = true,
	BuildingZone = { 0, 0 }
    })

-- Register Main prefab nodes
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/step_0_Ladder_" .. _nameFbx .. "_RootPart", _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB")

-- Register the root part
    CustomDecoration:register({
	DataType = "BUILDING_PART",
	Id = _PrefixAsset .. _nameAsset .. "_ROOT_PART",
	Name = _PrefixAsset .. _nameAsset .. "_ROOT_NAME",
	Description = _PrefixAsset .. _nameAsset .. "_ROOT_DESC",
	Category = "DECORATION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB",
		EndPart = _PrefixAsset .. "TOP_" .. _nameAsset .. "_PART",
		FillerList = {
			_PrefixAsset .. "TILING2_PART"
                },
		BasementFillerList = {
			_PrefixAsset .. "TILING1_PART"
         	},
		MinimumScale = 0,
		BasementScale = 1,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = 0 }
		}
	}
    })

-- Override building part components properties (generated by the building asset processor) to add building zones
    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/step_0_Ladder_" .. _nameFbx .. "_RootPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0, 0 }
    })
end

registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "door1", "WOODEN_DOOR_1", 1)
registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "door2", "WOODEN_DOOR_2", 1)
registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "door3", "WOODEN_DOOR_3", 1)
registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "door4", "WOODEN_DOOR_4", 1)
registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "door5", "WOODEN_DOOR_5", 1)
registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "door6", "WOODEN_DOOR_6", 1)
registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "window1", "WOODEN_WINDOW_1", 1)
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window2", "WOODEN_WINDOW_2", 1)
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window3", "WOODEN_WINDOW_3", 1)
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window4", "WOODEN_WINDOW_4", 1)
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window5", "WOODEN_WINDOW_5", 1)
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window6", "WOODEN_WINDOW_6", 1)
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window7", "WOODEN_WINDOW_7", 1)
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window8", "WOODEN_WINDOW_8", 1)
registerDefaultWoodenDecorationPart("decoration3", "commonDecoration", "roundWindow1", "WOODEN_ROUND_WINDOW", 1)
registerDefaultWoodenDecorationPart("stairs", "commonDecoration", "stair1", "WOODEN_STAIRS_1", 2)


